@@ -58,6 +58,8 @@ use base qw /Petal::Canonicalizer::XML/;
 #   <?petal:if name="blah"?><foo>...
 sub StartTag
 {
+    Petal::load_code_generator(); # we will use it later
+
     my $class = shift;
     push @Petal::Canonicalizer::XML::NodeStack, {};
     return if ($class->_is_inside_content_or_replace());
@@ -95,7 +97,7 @@ sub StartTag
 		$command =~ s/^\$//;
 		$command =~ s/^\{//;
 		$command =~ s/\}$//;
-		$command = Petal::XML_Encode_Decode::encode_backslash_semicolon ($command);
+		$command = $class->_encode_backslash_semicolon ($command);
 		$command = "<?var name=\"$command\"?>";
 		$text =~ s/\Q$var\E/$command/g;
 	    }
@@ -148,7 +150,7 @@ sub StartTag
 	{
 	    if (defined $att->{"$petal:omit-tag"})
 	    {
-		my $expression = $att->{"$petal:omit-tag"};
+		my $expression = $att->{"$petal:omit-tag"} = 'string:1';
 		$Petal::Canonicalizer::XML::NodeStack[$#Petal::Canonicalizer::XML::NodeStack]->{'omit-tag'} = $expression;
 		push @Petal::Canonicalizer::XML::Result, (defined $att_str and $att_str) ?
 		    "<?if name=\"false:$expression\"?><$tag $att_str /><?end?>" :
@@ -163,7 +165,7 @@ sub StartTag
 	{
 	    if (defined $att->{"$petal:omit-tag"})
 	    {
-		my $expression = $att->{"$petal:omit-tag"};
+		my $expression = $att->{"$petal:omit-tag"} || 'string:1';
 		$Petal::Canonicalizer::XML::NodeStack[$#Petal::Canonicalizer::XML::NodeStack]->{'omit-tag'} = $expression;
 		push @Petal::Canonicalizer::XML::Result, (defined $att_str and $att_str) ?
 		    "<?if name=\"false:$expression\"?><$tag $att_str><?end?>" :
